@@ -96,9 +96,7 @@ class Scope:
                 self._ctes.append(node)
             elif isinstance(node, (exp.Subquery, exp.Unnest, exp.Lateral)):
                 self._derived_tables.append(node)
-            elif isinstance(node, exp.Subqueryable) and not isinstance(
-                node.parent, (exp.CTE, exp.Subquery)
-            ):
+            elif isinstance(node, exp.Subqueryable):
                 self._subqueries.append(node)
 
         self._collected = True
@@ -189,11 +187,7 @@ class Scope:
                 for column in scope.external_columns
             ]
 
-            # Expression.named_selects also includes unaliased columns.
-            # In this case, we want to be sure to only include selects that are aliased.
-            aliased_outputs = {
-                e.alias for e in self.expression.expressions if isinstance(e, exp.Alias)
-            }
+            named_outputs = {e.alias_or_name for e in self.expression.expressions}
 
             self._columns = [
                 c
@@ -202,7 +196,7 @@ class Scope:
                 or not (
                     # In some dialects, these clauses can reference output columns
                     c.find_ancestor(exp.Group, exp.Order, exp.Qualify)
-                    and c.name in aliased_outputs
+                    and c.name in named_outputs
                 )
             ]
         return self._columns
@@ -337,7 +331,7 @@ def _traverse_scope(scope):
     elif isinstance(scope.expression, (exp.Lateral, exp.Unnest)):
         pass
     else:
-        raise OptimizeError(f"Unexpected expression type: {scope.expression}")
+        raise OptimizeError(f"Unexpected expression type: {type(scope.expression)}")
     yield scope
 
 
@@ -431,5 +425,6 @@ def _walk_next_scope(expression):
     This will yield the Select or Union node itself, but it won't recurse any further.
     """
     yield from expression.dfs(
-        prune=lambda n, *_: isinstance(n, exp.Subqueryable) and n is not expression
+        prune=lambda n, *_: isinstance(n, (exp.Subqueryable, exp.Subquery, exp.CTE))
+        and n is not expression
     )
